/*
    This file is part of ben -- a task scheduler for distributed computations
    Copyright (C) 2012-2019  Laurent Poirrier

    ben is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 3 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef BEN_PROTOCOL_H
#define BEN_PROTOCOL_H
#include <stdint.h>
#include "buffer.h"

/*

packet structure:

- magic number		(4 bytes lsb first integer)
- header		(4 bytes lsb first integer)
- payload size		(8 bytes lsb first integer)
- payload

code	type		encoding
 'i'	int		(4 bytes lsb first)
 'p'	uint64_t	(8 bytes lsb first)
 's'	string:
  - size_t {size}	(8 bytes lsb first integer, {size} = {length} + 1)
  - char *		({size - 1} bytes)
  - zero byte		(1 byte, mandatory)
 'd'    raw data:
  - size_t {size}	(8 bytes lsb first integer)
  - void *		({size} bytes)

proto_append():

  To {'i', 'p', 's'} corresponds one argument providing the data.
  
  To {'d'} correspond two arguments:
  
  - a pointer to the data
  - a pointer to a size_t, the size of the data

proto_fetch():

  To {'i', 'p', 's'} corresponds one argument, a pointer to the returned data

  To {'d'} correspond two arguments:
  
  - a pointer to the returned data
  - a pointer to a returned size_t, the size of the returned data

*/

// Sending
void proto_append(buffer *b, int magic, int header, const char *fmt, ...);

// Receiving
int proto_prepare(buffer *b, int magic, size_t max_size);
int proto_ready(buffer *b);
int proto_header(buffer *b);
int proto_fetch(buffer *b, const char *fmt, ...);

#endif

