/*
    This file is part of ben -- a task scheduler for distributed computations
    Copyright (C) 2012-2019  Laurent Poirrier

    ben is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 3 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#include <stdio.h>
#include "array.h"
#include "buffer.h"
#include "strlist.h"

// ***************************************************************************
// 
// ***************************************************************************
void strlist_init(strlist *a)
{
	array_init(a, sizeof(char *), 0);
}

void strlist_clear(strlist *a)
{
	array_clear(a);
}

void strlist_reset(strlist *a)
{
	array_reset(a);
}

char **strlist_get(strlist *a, size_t n)
{
	array_get(a, n);
	return((char **)a->data);
}

char **strlist_data(strlist *a)
{
	return((char **)a->data);
}

void strlist_append(strlist *a, char **l, size_t n)
{
	array_append(a, l, n);
}


void strlist_append_one(strlist *a, char *str)
{
	size_t o;
	
	o = a->n;
	array_get(a, o + 1);
	
	((char **)a->data)[o] = str;
}

// ***************************************************************************
// 
// ***************************************************************************
void strlist_parse(strlist *a, char *str)
{
	char *o, *p;
	
	o = str;
	
	while (1) {
		while ((*o > 0) && (*o <= ' '))
			o++;
		
		if (*o == 0)
			return;
		
		strlist_append_one(a, o);
		
		p = o;
		
		while ((*p < 0) || (*p > ' '))
			p++;
		
		if (*p == 0)
			return;
		
		*p = 0;
		o = p + 1;
	}
}


