/*
    This file is part of ben -- a task scheduler for distributed computations
    Copyright (C) 2012-2019  Laurent Poirrier

    ben is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 3 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef BEN_XMEM_H
#define BEN_XMEM_H
#include <stdlib.h>
#include <string.h>
#include <stdarg.h>

// failsafe funcs
void *dxmalloc(size_t n, const char *what,
	const char *func, const char *file, int line);
void *dxrealloc(void *p, size_t n, const char *pname, const char *what,
	const char *func, const char *file, int line);

char *dxstrdup(char *s, const char *what,
	const char *func, const char *file, int line);

#define xmalloc(n)	dxmalloc(n, #n, __func__, __FILE__, __LINE__)
#define xrealloc(p, n)	dxrealloc(p, n, #p, #n, __func__, __FILE__, __LINE__)
#define xfree(p)	free(p)

#define xstrdup(s)	dxstrdup(s, #s, __func__, __FILE__, __LINE__)

char *vxprintf(size_t *len_r, const char *format, va_list ap);
char *xprintf(size_t *len_r, const char *format, ...);

int vxsnprintf(char *buff, size_t size, const char *format, va_list ap);
int xsnprintf(char *buff, size_t size, const char *format, ...);


#endif

